@@ -1,11 +1,10 @@
 import re
-from dsdl.types.field import Field
 from prettytable import PrettyTable
 
 FIELD_VISUALIZE_ORDER = {  # 定义画图时的先后顺序，数值越小的越先画
     "text": 40,
     "bbox": 20,
-    "rotatebbox": 20,
+    "rotatedbbox": 20,
     "polygon": 10,
     "label": 30,
     "keypoint": 15,
@@ -20,11 +19,6 @@ class Util:
     def sort_field(field_lst):
         return sorted(list(field_lst), key=lambda k: FIELD_VISUALIZE_ORDER.get(k, -1))
 
-    @staticmethod
-    def extract_key(field_obj: Field):
-        field_cls_name = field_obj.__class__.__name__
-        return "$" + field_cls_name.replace("Field", "").lower()
-
     @staticmethod
     def get_first_item(dic):
         if len(dic) == 0:
@@ -60,7 +54,7 @@ class Util:
             param, value = item
             param = param.strip()
             value = value.strip()
-            res[param] = [value]
+            res[param] = value
 
         return res
 
