@@ -14,6 +14,10 @@ class DefineSyntaxError(SyntaxError):
     pass
 
 
+class DSDLImportError(ImportError):
+    pass
+
+
 class DefineTypeError(TypeError):
     pass
 
@@ -22,3 +26,9 @@ class FileReadError(TypeError):
     pass
 
 
+class InterruptError(RuntimeError):
+    pass
+
+
+class FieldNotFoundError(RuntimeError):
+    pass
